==> azure_mgmt_kubernetesconfiguration-0.2.0.crate: azure_mgmt_kubernetesconfiguration-0.2.0/README.md <==
# azure_mgmt_kubernetesconfiguration crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/kubernetesconfiguration/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2022-03`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-preview-2022-04` has 30 operations from 2 API versions: `2022-03-01`, `2022-04-02-preview`. Use crate feature `package-preview-2022-04` to enable. The operations will be in the `package_preview_2022_04` module.
- `package-2022-03` has 18 operations from 1 API versions: `2022-03-01`. Use crate feature `package-2022-03` to enable. The operations will be in the `package_2022_03` module.
- `package-preview-2022-01` has 22 operations from 1 API versions: `2022-01-01-preview`. Use crate feature `package-preview-2022-01` to enable. The operations will be in the `package_preview_2022_01` module.
- `package-preview-2021-11` has 22 operations from 1 API versions: `2021-11-01-preview`. Use crate feature `package-preview-2021-11` to enable. The operations will be in the `package_preview_2021_11` module.
- `package-2021-09` has 8 operations from 1 API versions: `2021-09-01`. Use crate feature `package-2021-09` to enable. The operations will be in the `package_2021_09` module.

==> azure_mgmt_kubernetesconfiguration-0.3.0.crate: azure_mgmt_kubernetesconfiguration-0.3.0/README.md <==
# azure_mgmt_kubernetesconfiguration crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/kubernetesconfiguration/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2022-03`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-preview-2022-04` has 30 operations from 2 API versions: `2022-03-01`, `2022-04-02-preview`. Use crate feature `package-preview-2022-04` to enable. The operations will be in the `package_preview_2022_04` module.
- `package-2022-03` has 18 operations from 1 API versions: `2022-03-01`. Use crate feature `package-2022-03` to enable. The operations will be in the `package_2022_03` module.
- `package-preview-2022-01-15` has 22 operations from 2 API versions: `2022-01-01-preview`, `2022-01-15-preview`. Use crate feature `package-preview-2022-01-15` to enable. The operations will be in the `package_preview_2022_01_15` module.
- `package-preview-2022-01` has 22 operations from 1 API versions: `2022-01-01-preview`. Use crate feature `package-preview-2022-01` to enable. The operations will be in the `package_preview_2022_01` module.
- `package-preview-2021-11` has 22 operations from 1 API versions: `2021-11-01-preview`. Use crate feature `package-preview-2021-11` to enable. The operations will be in the `package_preview_2021_11` module.
- `package-2021-09` has 8 operations from 1 API versions: `2021-09-01`. Use crate feature `package-2021-09` to enable. The operations will be in the `package_2021_09` module.
